@@ -13,15 +13,15 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #ifndef ACTIVE_SENSOR_H
 #define ACTIVE_SENSOR_H
 
-#ifdef HAVE_LIBMATENOTIFY
-#include <libmatenotify/notify.h>
-#include "active-sensor-libmatenotify.h"
+#ifdef HAVE_LIBNOTIFY
+#include <libnotify/notify.h>
+#include "active-sensor-libnotify.h"
 #endif
 
 #include "sensors-applet.h"
@@ -40,7 +40,7 @@ struct _ActiveSensor {
 
 	GtkTreeRowReference *sensor_row;
 
-#ifdef HAVE_LIBMATENOTIFY
+#ifdef HAVE_LIBNOTIFY
         NotifyNotification *notification[NUM_NOTIFS];
 #endif
 
